<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:lx="http://www.landxml.org/schema/LandXML-1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:landUtils="http://www.autodesk.com/land/civil/vcedit" xmlns:lxml="urn:lx_utils">
	<xsl:output method="html" encoding="UTF-8"/>
	<!--Description:SurfaceReport.
This form is valid for LandXML 0.88, 1.0 and 1.1 data.-->
	<!--CreatedBy:Autodesk Inc. -->
	<!--DateCreated:06/15/2002 -->
	<!--LastModifiedBy:Autodesk Inc. -->
	<!--DateModified:01/16/2006 -->
	<!--OutputExtension:html -->
	<!-- =========== JavaScript Include==== -->
	<xsl:include href="LandXMLUtils_JScript.xsl"/>
	<xsl:include href="Surface_Layout.xsl"/>
	<xsl:include href="General_Formating_JScript.xsl"/>
	<xsl:include href="Conversion_JScript.xsl"/>
	<xsl:include href="header.xsl"/>
	<!-- ================================= -->

	<xsl:param name="SourceLinearUnit" select="//lx:Units/*/@linearUnit"/>
    <xsl:param name="SourceAreaUnit" select="//lx:Units/*/@areaUnit"/>
	<xsl:param name="SourceVolumeUnit" select="//lx:Units/*/@volumeUnit"/>
	
	<xsl:template match="/">
		<xsl:call-template name="SetGeneralFormatParameters"/>
		<html>
			<head>
				<title>DGM-Bericht fuer <xsl:value-of select="//lx:Project/@name"/>
				</title>
				<style type="text/css">
				div{
				width:10in;
				font-family:Arial;
				}
				th{
				font-size:10pt;
				text-align:center;
								}
				td{
				padding:0.05in 0.45in;
				text-align:left;
				}
				tr{
				font-size:10pt;
				}
			</style>
			</head>
			<body>
				<div style="width:10in">
					<xsl:call-template name="AutoHeader">
						<xsl:with-param name="ReportTitle">DGM-Bericht</xsl:with-param>
						<xsl:with-param name="ReportDesc">
							<xsl:value-of select="//lx:Project/@name"/>
						</xsl:with-param>
					</xsl:call-template>
					<table width="100%" border="1">
						<tr>
							<td>
								<b>Linieneinheiten: </b><xsl:value-of select="//lx:Units/*/@linearUnit"/></td>
							<td>
								<b>Flaecheneinheiten: </b><xsl:value-of select="//lx:Units/*/@areaUnit"/></td>
							<td>
								<b>Volumeneinheiten: </b><xsl:value-of select="//lx:Units/*/@volumeUnit"/></td>
						</tr>
					</table>
					<xsl:apply-templates select="//lx:Surface"/>
					<xsl:apply-templates select="//lx:SurfVolume"/>
					<hr color="black"/>
				</div>
			</body>
		</html>
	</xsl:template>
	<xsl:template match="//lx:Surface">
	<hr color="black"/>
		<b>DGM: <xsl:value-of select="@name"/></b><br/>
		Description: <xsl:value-of select="@desc"/>
		<table width="100%" bgcolor="lightgreen">
			<tr>
				<td>2D Flaeche: <xsl:value-of select="./lx:Definition/@area2DSurf"/>
				</td>
				<td>3D Flaeche: <xsl:value-of select="./lx:Definition/@area3DSurf"/>
				</td>
			</tr>
			<tr>
				<td>Max Hoehe: <xsl:value-of select="./lx:Definition/@elevMax"/>
				</td>
				<td>Min. Hoehe: <xsl:value-of select="./lx:Definition/@elevMin"/>
				</td>
			</tr>
			<tr>
				<td>Anzahl Punkte: <xsl:value-of select="count(.//lx:P)"/>
				</td>
				<td>Anzahl Dreiecke: <xsl:value-of select="count(.//lx:F[not(@i)])"/>
				</td>
			</tr>
		</table>
	</xsl:template>
	<xsl:template match="//lx:SurfVolume">
	<hr color="black"/>
		<b>Mengenmodell: <xsl:value-of select="@name"/></b><br/>
		Description: <xsl:value-of select="@desc"/>
		<table width="100%" bgcolor="cyan">
			<tr>
				<td>Abtragsmenge: <xsl:value-of select="@volCut"/>
				</td>
				<td>Auftragsmenge: <xsl:value-of select="@volFill"/>
				</td>
				<td>Gesamtvolumen: <xsl:value-of select="@volTotal"/>
				</td>
			</tr>
			<tr>
				<td>Urgelaende: <xsl:value-of select="@surfCompare"/><br/>
				       Vergleichs-DGM: <xsl:value-of select="@surfBase"/>
				</td>
			</tr>
		</table>
	</xsl:template>
</xsl:stylesheet>
